@@ -12,18 +12,23 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-from oslo_log import log as logging
 import pecan
 
-from designate.api.v2.controllers import rest
-from designate.objects.adapters import DesignateAdapter
-from designate.objects import Tld
+from designate.openstack.common import log as logging
+from designate import schema
 from designate import utils
+from designate.api.v2.controllers import rest
+from designate.api.v2.views import tlds as tlds_view
+from designate.objects import Tld
+
 
 LOG = logging.getLogger(__name__)
 
 
 class TldsController(rest.RestController):
+    _view = tlds_view.TldsView()
+    _resource_schema = schema.Schema('v2', 'tld')
+    _collection_schema = schema.Schema('v2', 'tlds')
     SORT_KEYS = ['created_at', 'id', 'updated_at', 'name']
 
     @pecan.expose(template='json:', content_type='application/json')
@@ -35,10 +40,7 @@ class TldsController(rest.RestController):
         context = request.environ['context']
 
         tld = self.central_api.get_tld(context, tld_id)
-
-        LOG.info("Retrieved %(tld)s", {'tld': tld})
-
-        return DesignateAdapter.render('API_v2', tld, request=request)
+        return self._view.show(context, request, tld)
 
     @pecan.expose(template='json:', content_type='application/json')
     def get_all(self, **params):
@@ -47,20 +49,17 @@ class TldsController(rest.RestController):
         context = request.environ['context']
 
         # Extract the pagination params
-        marker, limit, sort_key, sort_dir = utils.get_paging_params(
-                context, params, self.SORT_KEYS)
+        marker, limit, sort_key, sort_dir = self._get_paging_params(params)
 
         # Extract any filter params.
-        accepted_filters = ('name', )
-        criterion = self._apply_filter_params(
-            params, accepted_filters, {})
+        accepted_filters = ('name')
+        criterion = dict((k, params[k]) for k in accepted_filters
+                         if k in params)
 
         tlds = self.central_api.find_tlds(
             context, criterion, marker, limit, sort_key, sort_dir)
 
-        LOG.info("Retrieved %(tlds)s", {'tlds': tlds})
-
-        return DesignateAdapter.render('API_v2', tlds, request=request)
+        return self._view.list(context, request, tlds)
 
     @pecan.expose(template='json:', content_type='application/json')
     def post_all(self):
@@ -70,23 +69,20 @@ class TldsController(rest.RestController):
         context = request.environ['context']
         body = request.body_dict
 
-        tld = DesignateAdapter.parse('API_v2', body, Tld())
+        # Validate the request conforms to the schema
+        self._resource_schema.validate(body)
 
-        tld.validate()
+        # Convert from APIv2 -> Central format
+        values = self._view.load(context, request, body)
 
         # Create the tld
-        tld = self.central_api.create_tld(context, tld)
-
-        LOG.info("Created %(tld)s", {'tld': tld})
-
+        tld = self.central_api.create_tld(context, Tld(**values))
         response.status_int = 201
 
-        tld = DesignateAdapter.render('API_v2', tld, request=request)
-
-        response.headers['Location'] = tld['links']['self']
-
+        response.headers['Location'] = self._view._get_resource_href(request,
+                                                                     tld)
         # Prepare and return the response body
-        return tld
+        return self._view.show(context, request, tld)
 
     @pecan.expose(template='json:', content_type='application/json')
     @pecan.expose(template='json:', content_type='application/json-patch+json')
@@ -97,23 +93,28 @@ class TldsController(rest.RestController):
         context = request.environ['context']
         body = request.body_dict
         response = pecan.response
-        if request.content_type == 'application/json-patch+json':
-            raise NotImplementedError('json-patch not implemented')
 
         # Fetch the existing tld
         tld = self.central_api.get_tld(context, tld_id)
 
-        tld = DesignateAdapter.parse('API_v2', body, tld)
+        # Convert to APIv2 Format
+        tld_data = self._view.show(context, request, tld)
 
-        tld.validate()
+        if request.content_type == 'application/json-patch+json':
+            raise NotImplemented('json-patch not implemented')
+        else:
+            tld_data = utils.deep_dict_merge(tld_data, body)
 
-        tld = self.central_api.update_tld(context, tld)
+            # Validate the new set of data
+            self._resource_schema.validate(tld_data)
 
-        LOG.info("Updated %(tld)s", {'tld': tld})
+            # Update and persist the resource
+            tld.update(self._view.load(context, request, body))
+            tld = self.central_api.update_tld(context, tld)
 
         response.status_int = 200
 
-        return DesignateAdapter.render('API_v2', tld, request=request)
+        return self._view.show(context, request, tld)
 
     @pecan.expose(template=None, content_type='application/json')
     @utils.validate_uuid('tld_id')
@@ -123,9 +124,7 @@ class TldsController(rest.RestController):
         response = pecan.response
         context = request.environ['context']
 
-        tld = self.central_api.delete_tld(context, tld_id)
-
-        LOG.info("Deleted %(tld)s", {'tld': tld})
+        self.central_api.delete_tld(context, tld_id)
 
         response.status_int = 204
 
