@@ -1,6 +1,6 @@
-# Copyright 2014 Rackspace Inc.
+# Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
-# Author: Tim Simmons <tim.simmons@rackspace.com>
+# Author: Kiall Mac Innes <kiall@hp.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -14,34 +14,24 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 import sys
-import warnings
 
-from oslo_log import log as logging
-from oslo_reports import guru_meditation_report as gmr
+from oslo.config import cfg
 
-from designate.agent import service as agent_service
-import designate.conf
-from designate import heartbeat_emitter
+from designate.openstack.common import log as logging
 from designate import service
 from designate import utils
-from designate import version
+from designate.agent import service as agent_service
 
 
-CONF = designate.conf.CONF
+CONF = cfg.CONF
 CONF.import_opt('workers', 'designate.agent', group='service:agent')
 
 
 def main():
     utils.read_config('designate', sys.argv)
-    logging.setup(CONF, 'designate')
-    gmr.TextGuruMeditation.setup_autorun(version)
+    logging.setup('designate')
 
-    warnings.warn('The designate agent process is deprecated as of the '
-                  'Antelope (2023.1) release and will be removed in the '
-                  '"C" release.', DeprecationWarning)
-
-    server = agent_service.Service()
-    heartbeat = heartbeat_emitter.get_heartbeat_emitter(server.service_name)
+    server = agent_service.Service.create(
+        binary='designate-agent')
     service.serve(server, workers=CONF['service:agent'].workers)
-    heartbeat.start()
     service.wait()
