@@ -34,6 +34,10 @@ class Backend(Exception):
     pass
 
 
+class NSD4SlaveBackendError(Backend):
+    pass
+
+
 class NotImplemented(Base, NotImplementedError):
     pass
 
@@ -42,6 +46,23 @@ class ConfigurationError(Base):
     error_type = 'configuration_error'
 
 
+class UnknownFailure(Base):
+    error_code = 500
+    error_type = 'unknown_failure'
+
+
+class CommunicationFailure(Base):
+    error_code = 504
+    error_type = 'communication_failure'
+
+
+class NeutronCommunicationFailure(CommunicationFailure):
+    """
+    Raised in case one of the alleged Neutron endpoints fails.
+    """
+    error_type = 'neutron_communication_failure'
+
+
 class NoServersConfigured(ConfigurationError):
     error_code = 500
     error_type = 'no_servers_configured'
@@ -66,6 +87,48 @@ class BadRequest(Base):
     error_type = 'bad_request'
 
 
+class InvalidUUID(BadRequest):
+    error_type = 'invalid_uuid'
+
+
+class NetworkEndpointNotFound(BadRequest):
+    error_type = 'no_endpoint'
+    error_code = 403
+
+
+class MarkerNotFound(BadRequest):
+    error_type = 'marker_not_found'
+
+
+class ValueError(BadRequest):
+    error_type = 'value_error'
+
+
+class InvalidMarker(BadRequest):
+    error_type = 'invalid_marker'
+
+
+class InvalidSortDir(BadRequest):
+    error_type = 'invalid_sort_dir'
+
+
+class InvalidLimit(BadRequest):
+    error_type = 'invalid_limit'
+
+
+class InvalidSortKey(BadRequest):
+    error_type = 'invalid_sort_key'
+
+
+class InvalidJson(BadRequest):
+    error_type = 'invalid_json'
+
+
+class InvalidOperation(BadRequest):
+    error_code = 400
+    error_type = 'invalid_operation'
+
+
 class UnsupportedAccept(BadRequest):
     error_code = 406
     error_type = 'unsupported_accept'
@@ -81,19 +144,19 @@ class InvalidDomainName(Base):
     error_type = 'invalid_domain_name'
 
 
-class InvalidTLD(Base):
+class InvalidRecordSetName(Base):
     error_code = 400
-    error_type = 'invalid_tld'
+    error_type = 'invalid_recordset_name'
 
 
-class InvalidRecordName(Base):
+class InvalidRecordSetLocation(Base):
     error_code = 400
-    error_type = 'invalid_record_name'
+    error_type = 'invalid_recordset_location'
 
 
-class InvalidRecordLocation(Base):
+class InvalidTTL(Base):
     error_code = 400
-    error_type = 'invalid_record_location'
+    error_type = 'invalid_ttl'
 
 
 class DomainHasSubdomain(Base):
@@ -104,9 +167,11 @@ class DomainHasSubdomain(Base):
 class Forbidden(Base):
     error_code = 403
     error_type = 'forbidden'
+    expected = True
 
 
 class Duplicate(Base):
+    expected = True
     error_code = 409
     error_type = 'duplicate'
 
@@ -127,11 +192,30 @@ class DuplicateDomain(Duplicate):
     error_type = 'duplicate_domain'
 
 
+class DuplicateTld(Duplicate):
+    error_type = 'duplicate_tld'
+
+
+class DuplicateRecordSet(Duplicate):
+    error_type = 'duplicate_recordset'
+
+
 class DuplicateRecord(Duplicate):
     error_type = 'duplicate_record'
 
 
+class DuplicateBlacklist(Duplicate):
+    error_type = 'duplicate_blacklist'
+
+
+class MethodNotAllowed(Base):
+    expected = True
+    error_code = 405
+    error_type = 'method_not_allowed'
+
+
 class NotFound(Base):
+    expected = True
     error_code = 404
     error_type = 'not_found'
 
@@ -148,14 +232,30 @@ class TsigKeyNotFound(NotFound):
     error_type = 'tsigkey_not_found'
 
 
+class BlacklistNotFound(NotFound):
+    error_type = 'blacklist_not_found'
+
+
 class DomainNotFound(NotFound):
     error_type = 'domain_not_found'
 
 
+class TldNotFound(NotFound):
+    error_type = 'tld_not_found'
+
+
+class RecordSetNotFound(NotFound):
+    error_type = 'recordset_not_found'
+
+
 class RecordNotFound(NotFound):
     error_type = 'record_not_found'
 
 
+class ReportNotFound(NotFound):
+    error_type = 'report_not_found'
+
+
 class LastServerDeleteNotAllowed(BadRequest):
     error_type = 'last_server_delete_not_allowed'
 
