@@ -14,16 +14,15 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 from designate.openstack.common import log as logging
+from designate.tests import TestCase
 from designate.notification_handler.nova import NovaFixedHandler
 from designate.tests.test_notification_handler import \
-    NotificationHandlerTestCase
+    NotificationHandlerMixin
 
 LOG = logging.getLogger(__name__)
 
 
-class NovaFixedHandlerTest(NotificationHandlerTestCase):
-    __test__ = True
-
+class NovaFixedHandlerTest(TestCase, NotificationHandlerMixin):
     def setUp(self):
         super(NovaFixedHandlerTest, self).setUp()
 
@@ -39,26 +38,30 @@ class NovaFixedHandlerTest(NotificationHandlerTestCase):
 
         self.assertIn(event_type, self.plugin.get_event_types())
 
-        # Ensure we start with 0 records
+        criterion = {'domain_id': self.domain_id}
+
+        # Ensure we start with 2 records
         records = self.central_service.find_records(self.admin_context,
-                                                    self.domain_id)
+                                                    criterion)
+        # Should only be SOA and NS records
+        self.assertEqual(2, len(records))
 
-        self.assertEqual(0, len(records))
+        self.plugin.process_notification(
+            self.admin_context, event_type, fixture['payload'])
 
-        self.plugin.process_notification(event_type, fixture['payload'])
-
-        # Ensure we now have exactly 1 record
+        # Ensure we now have exactly 1 more record
         records = self.central_service.find_records(self.admin_context,
-                                                    self.domain_id)
+                                                    criterion)
 
-        self.assertEqual(len(records), 1)
+        self.assertEqual(3, len(records))
 
     def test_instance_delete_start(self):
         # Prepare for the test
         start_event_type = 'compute.instance.create.end'
         start_fixture = self.get_notification_fixture('nova', start_event_type)
 
-        self.plugin.process_notification(start_event_type,
+        self.plugin.process_notification(self.admin_context,
+                                         start_event_type,
                                          start_fixture['payload'])
 
         # Now - Onto the real test
@@ -67,16 +70,19 @@ class NovaFixedHandlerTest(NotificationHandlerTestCase):
 
         self.assertIn(event_type, self.plugin.get_event_types())
 
+        criterion = {'domain_id': self.domain_id}
+
         # Ensure we start with at least 1 record
         records = self.central_service.find_records(self.admin_context,
-                                                    self.domain_id)
+                                                    criterion)
 
-        self.assertGreaterEqual(len(records), 1)
+        self.assertEqual(3, len(records))
 
-        self.plugin.process_notification(event_type, fixture['payload'])
+        self.plugin.process_notification(
+            self.admin_context, event_type, fixture['payload'])
 
         # Ensure we now have exactly 0 records
         records = self.central_service.find_records(self.admin_context,
-                                                    self.domain_id)
+                                                    criterion)
 
-        self.assertEqual(0, len(records))
+        self.assertEqual(2, len(records))
