@@ -13,13 +13,13 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from designate.openstack.common import wsgi
+from designate.openstack.deprecated import wsgi
 
 
 class Middleware(wsgi.Middleware):
     @classmethod
     def factory(cls, global_config, **local_conf):
-        """ Used for paste app factories in paste.deploy config files """
+        """Used for paste app factories in paste.deploy config files"""
 
         def _factory(app):
             return cls(app, **local_conf)
